const URL = require('whatwg-url')
const warning = require('warning')

const IdentifierFormat = /^((?:@[^\/]+\/)?[^\/]+)(\/.*)?$/

const parseBareIdentifier = (identifier) => {
  const match = IdentifierFormat.exec(identifier)

  return {
    name: match[1],
    file: match[2] || ''
  }
}

module.exports = (dependencies = {}, urlFormat = 'https://unpkg.com/%s?module') => {
  return {
    visitor: {
      ImportDeclaration(path) {
        if ([ '.', '/' ].indexOf(path.node.source.value.charAt(0)) >= 0)
          return // local path

        if (URL.parseURL(path.node.source.value) !== 'failure')
          return // valid URL

        const { name, file } = parseBareIdentifier(path.node.source.value)

        warning(
          dependencies[name],
          'Missing version info for package "%s" in dependencies; falling back to "latest"',
          name
        )

        const version = dependencies[name] || 'latest'
        const url = urlFormat.replace('%s', `${name}@${version}${file}`)

        path.node.source.value = url
      }
    }
  }
}
